@@ -53,22 +53,22 @@ def team_converter(team_id):
     team_map = {
         1: "Arsenal",
         2: "Aston Villa",
-        3: "Bournemouth",
-        4: "Brighton",
-        5: "Burnley",
-        6: "Chelsea",
-        7: "Crystal Palace",
-        8: "Everton",
+        3: "Brighton",
+        4: "Burnley",
+        5: "Chelsea",
+        6: "Crystal Palace",
+        7: "Everton",
+        8: "Fulham",
         9: "Leicester",
-        10: "Liverpool",
-        11: "Man City",
-        12: "Man Utd",
-        13: "Newcastle",
-        14: "Norwich",
+        10: "Leeds",
+        11: "Liverpool",
+        12: "Man City",
+        13: "Man Utd",
+        14: "Newcastle",
         15: "Sheffield Utd",
         16: "Southampton",
         17: "Spurs",
-        18: "Watford",
+        18: "West Brom",
         19: "West Ham",
         20: "Wolves",
         None: None
@@ -81,22 +81,22 @@ def short_name_converter(team_id):
     short_name_map = {
         1: "ARS",
         2: "AVL",
-        3: "BOU",
-        4: "BHA",
-        5: "BUR",
-        6: "CHE",
-        7: "CRY",
-        8: "EVE",
+        3: "BHA",
+        4: "BUR",
+        5: "CHE",
+        6: "CRY",
+        7: "EVE",
+        8: "FUL",
         9: "LEI",
-        10: "LIV",
-        11: "MCI",
-        12: "MUN",
-        13: "NEW",
-        14: "NOR",
+        10: "LEE",
+        11: "LIV",
+        12: "MCI",
+        13: "MUN",
+        14: "NEW",
         15: "SHU",
         16: "SOU",
         17: "TOT",
-        18: "WAT",
+        18: "WBA",
         19: "WHU",
         20: "WOL",
         None: None
